// OpenLP Mobile Remote
// ---------------------------------------------------------------------------
// Copyright (c) 2008-2019 OpenLP Developers
// ---------------------------------------------------------------------------
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

import 'package:bloc/bloc.dart';
import 'package:equatable/equatable.dart';
import 'package:meta/meta.dart';

import '../network/api.dart' as api;

enum DisplayOptionsState { waiting, success, failure }

@immutable
abstract class SetDisplayTypeEvent extends Equatable {
  final String type;
  SetDisplayTypeEvent(this.type, [List props = const <dynamic>[]])
      : super(props);
}

class SetDisplayTypeBlankEvent extends SetDisplayTypeEvent {
  SetDisplayTypeBlankEvent() : super('blank');
}

class SetDisplayTypeThemeEvent extends SetDisplayTypeEvent {
  SetDisplayTypeThemeEvent() : super('theme');
}

class SetDisplayTypeDesktopEvent extends SetDisplayTypeEvent {
  SetDisplayTypeDesktopEvent() : super('desktop');
}

class SetDisplayTypeShowEvent extends SetDisplayTypeEvent {
  SetDisplayTypeShowEvent() : super('show');
}

class DisplayOptionsDialogBloc
    extends Bloc<SetDisplayTypeEvent, DisplayOptionsState> {
  @override
  DisplayOptionsState get initialState => DisplayOptionsState.waiting;

  void setBlankScreen() {
    dispatch(SetDisplayTypeBlankEvent());
  }

  void setThemeScreen() {
    dispatch(SetDisplayTypeThemeEvent());
  }

  void setDesktopScreen() {
    dispatch(SetDisplayTypeDesktopEvent());
  }

  void setFullProjection() {
    dispatch(SetDisplayTypeShowEvent());
  }

  @override
  Stream<DisplayOptionsState> mapEventToState(
      SetDisplayTypeEvent event) async* {
    try {
      await api.setDisplayState(event.type);
      yield DisplayOptionsState.success;
    } catch (e) {
      yield DisplayOptionsState.failure;
    }
    yield DisplayOptionsState.waiting;
  }
}
